@@ -11,17 +11,19 @@ __email__ = 'matt@joyce.nyc'
 __copyright__ = 'Copyright 2016, Symphony Communication Services LLC'
 
 
-import symphony
+import symphonybinding
 
 from .base import Base
 
 
 class Agent(Base):
 
-    def __init__(self, url, session, keymngr, crt, key):
+    def __init__(self, url, session, keymngr):
         self.__url__ = url
         self.__session__ = session
         self.__keymngr__ = keymngr
-        self.__crt__ = crt
-        self.__key__ = key
-        self.__rest__ = symphony.RESTful(self.__url__, self.__session__, self.__keymngr__, self.__crt__, self.__key__)
+        try:
+            CG = symphonybinding.SymCodegen()
+            self.__agent__ = CG.agent_cg(self.__url__)
+        except Exception as err:
+            print (err)
